local addonName, addonTable = ...

local calendarReplacementData = {
	contextMenu = {
		[false] = CALENDAR_TENTATIVE_INVITATION,
		[true] = "Accept invitation as late"
	},
	tooltip = {
		[false] = CalendarViewEventTentativeButton_OnEnter,
		[true] =
		function(self)
			GameTooltip:SetOwner(self, "ANCHOR_LEFT")
			GameTooltip:SetText("Sets your status to Late for this event", nil, nil, nil, nil, true)
			GameTooltip:Show()
		end
	},
	button = {
		[false] = CALENDAR_STATUS_TENTATIVE,
		[true] = "Late"
	},
	list = {
		[false] = CALENDAR_STATUS_TENTATIVE,
		[true] = "Late"
	}
}
local addonMessage = {
	prefix = "CalendarLate",
	reply = "Reply"
}


local loaded, reason = LoadAddOn("Blizzard_Calendar")
if not loaded then
	print("Calendar not loaded. Reason: ", reason)
end

local eventFrame = CreateFrame("Frame", addonName.."EventFrame", UIParent)
eventFrame:SetSize(1, 1)
eventFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT")
eventFrame:EnableMouse(false)
eventFrame:EnableKeyboard(false)
eventFrame:SetMovable(false)
eventFrame:RegisterEvent("CALENDAR_OPEN_EVENT")
eventFrame:RegisterEvent("CALENDAR_UPDATE_INVITE_LIST")
eventFrame:RegisterEvent("CHAT_MSG_ADDON")
C_ChatInfo.RegisterAddonMessagePrefix(addonMessage.prefix)
eventFrame.replies = {}
eventFrame:SetScript("OnEvent",
	function(self, event, ...)
		if event == "CHAT_MSG_ADDON" then
			local prefix, text, channel, sender, target, zoneChannelID, localID, name, instanceID = ...
			if prefix == addonMessage.prefix then
				if text:find("Check") then
					C_ChatInfo.SendAddonMessage(addonMessage.prefix, addonMessage.reply, "WHISPER", sender)
					print("A")
				elseif text:find(addonMessage.reply) then
					eventFrame.replies[sender] = true
				end
			end
		elseif event == "CALENDAR_OPEN_EVENT" or event == "CALENDAR_UPDATE_INVITE_LIST" then
			local eventInfo = C_Calendar.GetEventInfo()
			if type(eventInfo) ~= "table" then
				return
			end
			local shouldReplace = not not (eventInfo.title:lower():find("raid") or eventInfo.description:lower():find("raid"))

			CalendarViewEventTentativeButton:SetText(calendarReplacementData.button[shouldReplace])
			CalendarViewEventTentativeButton:SetScript("OnEnter", calendarReplacementData.tooltip[shouldReplace])
			local buttons
			if eventInfo.creator == UnitName("player") then
				CalendarCreateEventInviteListScrollFrame_Update()
				buttons = CalendarCreateEventInviteListScrollFrame.buttons
			else
				CalendarViewEventInviteListScrollFrame_Update()
				buttons = CalendarViewEventInviteListScrollFrame.buttons
			end
			for i = 1, #buttons, 1 do
				local currButton = _G[buttons[i]:GetName().."Status"]
				if currButton:GetText() == CALENDAR_STATUS_TENTATIVE then
					currButton:SetText(calendarReplacementData.list[shouldReplace])
				end
			end
		end
	end)

eventFrame.startCheck = function()
	wipe(eventFrame.replies)
	for i = 1, GetNumGuildMembers(), 1 do
		if select(9, GetGuildRosterInfo(i)) then
			eventFrame.replies[GetGuildRosterInfo(i)] = false
		end
	end
	C_ChatInfo.SendAddonMessage(addonMessage.prefix, "Check", "GUILD")
end